Module scale_bits::scale::format
source · Expand description
Types to describe the format of some SCALE encoded bits.
Structs
- A description of the format used to SCALE encode some bits.
Enums
- This is a runtime representation of the order that bits will be written to the specified
BitsStoreFormat. - This is a runtime representation of the store type that we’re targeting. These are equivalent to the
bitvecstore typesu8,u16and so on.