Module scale_bits::bits
source · Expand description
This module exposes a Bits type, which is a small, simple bit store
which is SCALE compatible with BitVec<u8, Lsb0>.
Structs
- This represents a sequence of boolean values, packed into bits.
- Returned from calling
into_iteronBitsvia thestd::iter::IntoIteratortrait. Allows iteration over each stored bit. - Returned from calling
Bits::iter(). Allows iteration over each stored bit.